bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 7. Aventiure
___________________________________________________ #### Auentv wie Gunthr ze Islande mit sinen gesellen chom
| ### Do> der chunic Gvnther so vil der burge sach ### vn– ovch die witen marche wie balder do sprach ### sagt mir frivnt Sivrit ist iv daz bechant ### wes sint dise burge vn– ovch daz herliche lant
###### 392 | ### Ine han bi minen ziten ine wolde lvge iehn ### so wol erbowen burge mere nie gesehen ### in deheinem ein lande als ir hie vor uns stat ### er mach wol wesen riche der si hie gebowen hat
###### 393 | ### Des antwrt Sifrit ez ist mir wol bekant [15v] ### ez ist frown Prvnhilt livt vn– lant ### vn– Isenstein div veste als <ir> mich hortet iehen ### da mvget ir noch hivte schoner frowen vil gesehn
###### 394 | ### Vn– wil iv helden raten ir habt einen mvot ### daz wir iehn geliche ia dvnchet ez mich gvot ### swenne wir noh hivte fvr Prvnhilde gan ### so mvzen wir mit sorgen for der kuniginnestan
| ### So wir die minneklichen bi ir gesinde sehn ### so svlt ir helede gvote wan einer rede iehen ### Gunther si min herre ich si sin eigen man ### so mag unser wille harte wol an ir ergan
###### 396 | ### Des waren si bereite swaz er si loben hiez ### durch ir vbermvete deheiner ez niht liez ### si iahen swes er wolde da von in wol geschach ### do der kunic Gvnther die schonen Prvnhilde sach
###### 397 | ### Ich enlob ez niht so verre durch den willen din ### so durch Chriemh' daz schone magedin ### div ist mir sam min sele vn– so min eigen lip ### ich wil daz gerne dienen daz si werde min wip
###### 398 | ### In den selben citen do was ir schiff gegan ### der burge also nahenn do sach der kunic stan ### oben in den venstern vil manige schone meit ### do begunde vragen der reche kvene vn– gemeit
###### 399 | ### Saget mir frivnt Sifrit durch den willen min ### bekennet ir die frowen vn– ovch div magedin ### di dort her nider schowent zvo zvns vf die flvot ### si gebarent dem geliche daz si hohe sint gemvot
| ### Do sprach der chune Sifrit ir svlt von hinnen spehn ### tovgen in dem mvote vn– svlt mir danne iehn ### welhe ir nemen woldet hetet irs gewalt ### daz tvn ich sprach do Gunther der ritter chven vn– balt
###### 401 | ### So sihe ih vnder in eine in ienem venster stan ### in snewizer wæte div ist so wolgetan ### die wellent miniv ovgen vil schoen ist <ir> der lip ### ob ich gewalt des hæte si mvse werden min wip
###### 402 | ### Dir hat erwelt vil rehte diner ovgen schin ### ez ist div starche Prvnhilt daz schone magedin ### die din herce minnet der lip vn– ovch der mvot ### elliv ir geberde div dvhte Guntheren gvot
###### 403 | ### Do hiez div kuniginne vz den venstern stan ### ir minneklichen meide sine solden niht da stan ### den vremden an ze sehene des waren si bereit ### waz do die frowen tæten daz ist vns sider ovch geseit
###### 404 | ### Gegen den vnchunden strichen si ir lip ### des ie site habeten div wætlichen wip ### an div engen venster chomen si gegan ### da si die rechen sahen daz wart durch schowen getan
| ### Ir waren niwan viere di da chomen in daz lant ### Sifrit der starche ein ross zoch an der hant ### daz sahen durch div venster div minneklichen wip ### des wart sit getivret des kunic Guntheres lip
###### 406 | ### Er habt im da bi zovme daz zierliche march ### gvot vn– schone vil michel vn– starch ### vnze der kunic Gvnther in den satel gesaz ### also dient im Sifrit des er doch sit vil gar vergaz
###### 407 | ### Do zoh er ovch daz sine von dem schiffe dan ### er hete solhen dienest selten ê getan ### daz er den stegereif gehabt ie helede mer ### daz sahen durch div venster [16r]die frowen schoen vn– her
###### 408 | ### Reht in einer maze den rittern vil gemeit ### von sneblancher varwe ir ross vn– ovch ir kleit ### ez waren vil geliche ir schilde wolgetan ### die luhten von den handen den vil wætlichen man
###### 409 | ### Ir sætele wol gesteinet ir fvrbuoge smal ### si riten herlichen fvr <Prunhilde> sal ### dar an so hiengen schellen von liehtem golde rot ### si chomen zv dem lande als ez ir ellen in gebot
###### 410 | ### Mit spern niwo sliffen mit swerten wol getan ### div uf die sporn giengen den wætlichen man ### div fvrten die vil chvenen scharpf vn– dar zv breit ### daz sach allez Prvnh' div vil minnekliche meit
| ### Mit im chom ovch Danchwart vn– Hagene ### nv hoeret disiv mære wie die degene ### von rabenswarzer varwe truogen richiv kleit ### ir schilde waren schone vil gvot michel vn– breit
###### 412 | ### Von India dem lande man sach si steine tragen ### die chos man an ir wete vil herliche wagen ### sie liezen ane hvote ir schiffel bi der flvot ### svs riten zv der burge die helde chuon vn– gvot
###### 413 | ### Sehs un– ahzech tuorne si sahen drinne stan ### dri palas wite vn– einen sal wolgetan ### von edelm marmelsteine grven alsam ein gras ### dar inne div kuniginne mit ir ingesinde was
###### 414 | ### Div porte stvnt entslozzen div bvrch vf getan ### do liefen in engegene die Prvnh' man ### vn– enpfiengen wol die chvenen in ir frowen lant ### ir ross man hiez behalten vn– ir schilde von der hant
###### 415 | ### Do sprach ein kamerære ir svlt uns geben div swert ### vn– ovch die liehten brvenne des sit ir vngewert ### sprach Hagene der chuone wir selbe wellens tragen ### do begunde in Sifrit da von div rehten mære sagn
###### 416 | ### Man pfligt in dirre burge daz wil ich iv sagen ### daz decheine geste hie waffen svln tragen ### ir svlt si lan behalten daz ist wolgetan ### daz tet do vil ungerne Hagen der Gvntheres man
| ### Den gesten hiez man schenchen vn– schaffen ir gemach ### vil manigen snellen rechen man da ze hove sach ### in fvrstenlicher wæte allenthalben gan ### da wart michel schowen an die vil chvenen getan
###### 418 | ### Do tet man Prvnhilde chvnt mit mæren ### daz da vremde rechen chomen wæren ### in vil richer wæte gevlozzen vof der flvot ### da von begunde vragen div magt schoen vn– gvot
###### 419 | ### Ir svlt mich lazen hoeren sprach div kunigin ### wer die vil vnchvnden rechen mvgin sin ### die in miner bverge so herliche stan ### vn– durch welhe schulde die helde her gevarn han
###### 420 | ### Do sprach ein ir gesinde frowe ich mach wol iehn ### daz ich ir deheinen nimere habe gesehn ### wan geliche Sifride einer drvnder stat ### den svlt ir wol enpfahen daz ist mit triwen min rat
###### 421 | ### Der ander der gesellen der ist so lobelich ### ob er gewalt des hete wol wær er kunic rich ### ob witen fursten landen ob er div mohte han ### man siht in bi den andern so rehte herliche stan
###### 422 | ### Der dritte der gesellen [16v]der ist vil <gremlich> ### vn– doch mit schome libe kuniginne rich ### von <swinden> sinen blichen der er so vil getvot ### er ist in sinen sinnen ich wæn vil grimme gemvot
| ### Der der iungest ist darvnder der ist so lobelich ### in magtlichen zvhten sihe ich den degen rich ### mit gvtem gelæze so minnekliche stan ### wir mohtenz fvrhten alle het im hie iemen iht getan
###### 424 | ### Swie blide er pflege der zvhte vn– swie schoen im si der lip ### er moehte wol erweinen vil wætlichiv wip ### swenner begunde zvernen sin lip ist so gestalt ### er ist in allen tvgenden ein degn chvene vn– balt
###### 425 | ### Do sprach div kuniginne nv brinch mir min gewant ### vn– ist der starche Sivrit chomen in daz lant ### durch willen miner minne ez gat im an den lip ### ine fvrht in niht so sere daz ich werde sin wip
###### 426 | ### Do wart chuniginne schiere wol gekleit ### do gie mit ir dannen vil manic schoniv meit ### wol hundert vn– mere gezieret was ir lip ### ez wolden sehen die geste div vilminneklichen wip
###### 427 | ### Da mit giengen rechen vzer Islant ### die Prvnhilde degene die trvgen swert enhant ### fvnf hundert oder mere daz was den gesten leit ### do stunden von dem sedele die helde chven vn– gemeit
| ### Do div kuniginne Sifriden sach ### div magt zvhtekliche zv dem rechen sprach ### sit willechomen Sivrit her in dizze lant ### waz iwer reise meine gern het ich daz erkant
###### 429 | ### Vil michel iwer genade min vrov Prunhilt ### daz ir mich rvchet grvzen fversten tohter milt ### vor diesem chvnem rechen der hie vor mir stat ### wander ist min herre der eren het ich gerne rat
###### 430 | ### Er ist geborn von Rine daz tvot er dir bechant ### er hat durch dinen willen gesvchet dizze lant ### der wil dich gerne minnen swaz im da von geschiht ### nv bedenche dihs bezite min herre erlêt dihs niht
###### 431 | ### Er ist geheizen Gunther vn– ist ein kunic her ### erwrber dine minne sone engert er nihtes mer ### ia gebot mir her ze varne der reche wolgetan ### wan daz ich entorste ich hietez gerne verlan
| ### Si sprach ist er din herre vi bistv sin man ### div spil div ich im teile vn– tarrer div bestan ### behabt er des die maisterschaft so minne ich sinen lip ### anders mvz er sterben ê ich werde sin wip
###### 433 | ### Do sprach von Tronege Hagene frow nv lat vns sehen ### iwer spil div starchen e daz iv mvse iehn ### Gunther min herre da mvsez herte sin ### er mach noch wol gewinnen ein also schone magedin
###### 434 | ### Den stein den sol er werfen vn– springen dar nach ### den ger mit mir schiezen lat iv niht sin ze gach ### des bedenchet ivch vil ebene sprach daz vil schone wip ### gebristet im an dem einen ez get iv allen an den lip
###### 435 | ### Sifrit der starche zv dem kunige trat ### allen sinen willen er in reden bat ### mit der kuniginne [17r]ez kunde im geschaden niht ### ez wirt al anders gendet des sich ir vbermvot versiht
###### 436 | ### < o> sprach der kunich Gunther kuniginnne her ### nv teilt swaz ir gebietet vn– wære is dannoch mer ### daz bestvnde ich alliz gerne durch iwern schonen lip ### min hovbet wil ich wagen irn werdet min wip
###### 437 | ### Do div kuniginne sine rede vernam ### der spile bat si gahen als ir do daz gezam ### si hiez ir dar gewinnen balde ir stritgewant ### eine veste brvnne vn– einen gvten schildes rant
###### 438 | ### Einn wafenhemde sidin daz leit an sich div meit ### daz in deheime strite wafen nIe versneit ### von pfelle vzer Libia ez was vil wolgetan ### von porten lieht gewerhte daz sach man schinen daran
###### 439 | ### Die zit wart disen rechen harte vil gedrevot ### Danchwart vn– Hagene die waren vngefrevot ### wiez dem kunige ergienge des sorget in der mvot ### si dahten unser reise ist vns rechen niht zegvot
| ### Die wile was ovch Sivrit der listige man ### e iz iemen erfunde in daz schiff gegan ### da er die tarnkappen verborgen ligen vant ### dar in slavf er vil schiere do was er niemen bechant
###### 441 | ### Er ilte hin widere do vant er rechen vil ### da div kuniginne teilte ir hohen spil ### dar gie er tovgenliche von listen daz geschach ### alle die da waren daz in da niemen gesach
###### 442 | ### Der rinch der was bezeiget da soldez spil geschehn ### vor manigem chvenem rechen die daz solden sehn ### mer danne sibenhundert die sah man waffen tragen ### swer daz spil gewnne daz ez die helde solden sagen
###### 443 | ### Do was nv komen Prvnhilt gewaffent man die vant ### sam ob si striten solde vmbe elliv kuniges lant ### ia trvoch si ob den siden vil manigen stahel zein ### ir minneklichiv varwe dar vnder herlichen schein
| ### Do chom ovch ir gesinde die trugen dar zehant ### von vil rotem golde einen liehten schildes rant ### mit stahel herten spangen vil michel vn– breit ### dar vnder spilen wolde div vil herliche meit
###### 445 | ### Der frowen schiltvezzel ein edel porte was ### dar vffe lagen steine gruoner denne ein gras ### die luhten maniger hande mit schine wider daz golt ### der si solde minnen der het iz hohe <verscolt>
###### 446 | ### Der schilt was under bvkelen als uns daz ist geseit ### wol drier hende dicke den tragen solde div meit ### von stale vn– ovch von golde rich er was genvoch ### den ir kamerære selbe vierder kvnne trvoch
###### 447 | ### Also der karche Hagene den schilt dar tragen sach ### in vil grozem unmvote der helt von Tronege sprach ### wie nv kunic Gunther wie vliesen wir den lip ### der ir da gert ze minnen div ist des valandes wip
###### 448 | ### Vernemt noch von ir wæte der hete si genuoch ### von Azagovch der siden einen waffenroch si trvoch ### vil edel un– vil riche ab des varwe schein ### von der kuniginne vil manic herlicher stein
| ### Do trvoch man dar der frowen swære un– dar zvo groz ### einen ger vil [17v]starchen den si alle <zite> schoz ### scarpf un– ungefvge michel vn– breit ### der ze sinen ecken harte vreislichen sneit
###### 450 | ### Von des geres swære hoeret wnder sagen ### wol vierdehalbiv mæsse was der zv geslagen ### in trvgen chvme drie Prvnhilde man ### Gvnther der vil chuone harte sorgen began
###### 451 | ### Er daht in sinem mvote waz sol dizze wesen ### der tivfel von der helle wie kunder da vor genesen ### vn– wær ich da ze Rine mit dem libe min ### si mveste hie vil lange vri fon miner minne sin
###### 452 | ### Im was in sinen sorgen daz wizzet leit genvoch ### allez sin gewæfen man im einen trvoch ### da wart der chunic riche wol gewaffent in ### vor leide het Hagene vil nach verwandelt den sin
| ### Do sprach von Burgonden der chvene Danchwart ### mich mvz immer riwen disiv hovevart ### nv hiezen wir ie rechen wie verliesen wir den lip ### sulen vns in disen landen nv verderben div wip
###### 454 | ### Mich mvet daz harte sere daz ich chom in daz lant ### vn– hete min brvoder Hagene sin waffen an der hant ### vn– ovch ich daz mine so nnohten sanfte gan ### durch ir vbermvote alle Prvnhilde man
###### 455 | ### Ich sage iv bi den triwen si soldenz wol bewarn ### vn– het ich tusint eide zeinem fride geswarn ### e daz ich sterben sæhe den lieben herren min ### ia mvesen lip verliesen daz vil schoene magedin
###### 456 | ### Wir solden vngevangen wol rvmen dizze lant ### ich un– min brvoder Danchwart heten wir daz gewant ### des wir ze not bedurfen vn– unser swert vil gvot ### so wrde wol gesenftet der frowen starchiv vbermvot
| ### Wol hort div kuniginne waz der degen sprach ### mit smielendem mvnde si vber ahsel sach ### nv er dunche sich so biderbe so tragt in ir gewant ### vn– ir vil scharpfen waffen gebt den rechen an die hant
###### 458 | ### Mir ist als mære daz si gewaffent sint ### als ob si bloze stuonden so sprach div kunigin ### ihen furhte niemens sterche den ich noh habe bechant ### ieh getrowe wol gedingen in strite vor sin eines hant
###### 459 | ### Do si div swert gewnnen also div magt gebot ### der vil chuone <Dancwart> wart von frevden rot ### nv spilen swes si wellen sprach der snelle man ### Gunther ist vnbetwngen sit daz wir unser wafen han
###### 460 | ### Div Prunhilde sterche vil groezlichen schein ### man braht ir zvo dem ringe einen swæren mermilstein ### groz un– vngefvge michel vn– wel ### in trvgen chvme zwelfe helde chven vn– snel
###### 461 | ### Den warf si zallen citen so si den ger verschoz ### der Burgonden sorge wrden harte groz ### wafen sprach do Hagene waz hat der kunic zetrvot ### ia soldes in der helle sin des vbeln tivfels brvot
| ### An vil wizen armen si die ermil want ### si begvnde sere vazzen den schilt an der hant ### den ger si hohe zvochte do giengez an den strit ### Gunther vn– Sivrit die vorhten Prvnhilde nit
###### 463 | ### Wær im der starche Sifrit niht schiere ze helfe chomen ### so hete si dem kunige sinen lip be[18r]nomen ### er gie dar tovgenliche vn– rvort im sine hant ### Gvnther sine liste vil harte sorekliche ervant
###### 464 | ### Waz hat mich gerveret gedaht der chvne man ### do sah er allenthalben er vant da niemen stan ### er sprach ich bin ez Sivrit der liebe <frivnt> din ### vor der kuniginne soltv gar ane angest sin
###### 465 | ### Den schilt gib mir von hende den la dv mich tragen ### vn– merche mine lere die dv mich hoerest sagn ### nv habe dv die geberde div werch wil ich began ### do er vernam div mêre der kunic trosten sich began
###### 466 | ### Nv hil dv mine liste daz ist uns beiden gvot ### sone mach div kuniginne ir <starchen> vbermvot ### an dir niht verenden des si doch willen hat ### nv sich wie angestliche si gein dir amme ringe stat
| ### Do <schoz> vil chreftichliche div vil starche meit ### den ger gein eime schilde michel vn– breit ### den trvg an siner hende daz <Sigelinde> kint ### daz fiwr spranch von stale alsam ez wæte der wimt
###### 468 | ### Des starchen geres snide so dvrch den schilt gebrach ### daz man daz fivr lovgen vz den ringen sach ### des schvzzes beide strvochten die vil starchen man ### si ertwelten si so sere daz si den lip nach heten lan
###### 469 | ### Sivride dem vil chvnen vom mvnde brast daz blvot ### vil balde spranch er widere do nam der helet gvot ### den ger den si geschozzen im hete durch den rant ### den frvmt ir do hin widere sin vil ellenthaftiv hant
###### 470 | ### Er daht ich wil niht schiezen daz schone magedin ### er kert des geres snide hindern rvcke sin ### mit der gerstangen schoz si der chvne man ### also chreftikliche daz si strvochen began
###### 471 | ### Daz fivr stavb vz stale sam iz tribe der wint ### den schvoz schoz mit ellen daz Sigelinde kint ### sine mohte mit ir chreften des schvzzes niht gestan ### ez enhet der chunic Gunther entriwen nimmer getan
| ### Prvnhilt div schoene wie balde si vf spranch ### Gvnther ritter edele des schuzzes habe danch ### si wande daz erz hete mit siner hant getan ### ir was dar nach geslichen ein verre kreftiger man
###### 473 | ### Do gie si hin vil balde zornich was ir mvot ### den stein den hvop si hohe div schone maget gvot ### si swanch in kreftekliche so verre von ir dan ### daz sin die chvne degene sere wndern began
###### 474 | ### Der stein der was gevallen wol zwelf klafter dan ### den wrf prach do mit sprunge div maget wol getan ### dar gie der herre Sifrit da der stein gelach ### Gunther in do wegete der helt in werfene pflach
###### 475 | ### Sifrit was vil chune dar zvo starch vn– lanch ### den stein den warf er verrer dar zvo er witer spranch ### daz was ein michel wnder vn– kunsteklich gench ### daz er mit dem sprunge den kunic Gunther doch trvch
| ### Der sprvnch der was ergangen der stein der was gelegen ### do sah man ander niemen wan Gunther den degn ### Prvnhilt div schone wart in zorne rot [18v] ### Sifrit het geverret des kunich Guntheres tot
###### 477 | ### Zvo zir ingesinde div kuniginne sprach ### do si zent des ringes den helt gesunden sach ### vil balde get her naher ir mage vn– mine man ### ir svlt dem kunech Gunther alle wesen vndertan
###### 478 | ### Do leiten die vil chvenen div wafen von der hant ### si bvten sich ze fvozen vz Burgonden lant ### Gunthere dem richen vil manic chvner man ### si wanden daz er hete div spil mit siner chraft getan
###### 479 | ### Er grvoztes minnekliche wander was tvgentrich ### do nam in bi der hende div magt lobelich ### si erlovbt im daz er solde haben da gewalt ### des frevte sich do Hagene der reche chven vn– balt
###### 480 | ### Si bat den ritter edele mit ir dannen gan ### in einen palas witen da was vil manic man ### durch vorhte manz dem degene deste baz erbot ### von Sifrides ellen si waren chomen vozer not
| ### Sifrit der snelle wiser was genvoch ### die sinen tarnkappen er aber behalten trvoch ### do gie er hin widere da vil der frowen saz ### er sprach zv dem chvnige vn– tet vil chundekliche daz
###### 482 | ### Wes bitet ir min herre wan beginnet ir der spil ### der iv div kuniginne teilet also vil ### vn– lazet vns daz schowen wie div sin getan ### sam ob er ir niht ensæhe gebart der listige man
###### 483 | ### Do sprach div kvniginne wie ist daz geschehn ### <daz> ir habt her Sifrit der spil niht gesehn ### div hie hat errungen div Guntheres hant ### des antwort ir Hagene vozer Burgonden lant
###### 484 | ### Da het ir also sere getrvebet vns den mvot ### do was bi dem schiffe Sifrit der helet gvot ### do der vogt von Rine daz spil an iv gewan ### des ist ez im vnkundich sprach do der Guntheres man
| ### So wol mich dirre mære sprach Sivrit der degn ### daz iwer hochverten ist alsus gelegn ### daz iemen lebt so chvene der iwer meister mvge gesin ### nv svlt ir maget edele vns volgen hinnen an den Rin
###### 486 | ### Do sprach div chuniginne des enchan noch niht ergan ### ez mvzen ê bevinden mage vn– mine man ### iane mag ich also lihte gervmen miniv lant ### di mine hohsten frivnde mvzen werden ê besant
###### 487 | ### Do hiez si boten riten allenthalben dan ### si besande alle ir friwnde mage vn– man ### die bat si chomen balde ze hove in Islant ### vn– hiez in gebn allen rich vn– herlich gewant
###### 488 | ### Si riten tægeliche spate vn– frvo ### der Prvnh'burge scharhafte zvo ### iara ia sprach Hagene waz haben wir getan ### wir erbeiten hie vil vbele der schonen Prvnhilde man
###### 489 | ### So si nv mit ir kreften choment in daz lant ### der Prvnhilde wille ist vns vnbechant ### waz ob si also zvrnet daz wir sin verlorn ### so ist vns div maget edele ze grozen sorgen geborn
| ### Do sprach der herre Sifrit daz sol ich understen ### des ir da habet sorge des enlaz ich niht ergen ### ich sol iv helfe bringen her in dizze lant [19r] ### vz erwelten degenen di iv noch wrden ie bechant
###### 491 | ### Irn svlt nach mir niht vragem ich wil hinnen varn ### got mvz iwer ere di zite wol bewarn ### ich chvm vil schiere widere vn– bringe iv tvsint man ### der aller besten degene der iemen chvnde gewan
###### 492 | ### Sone sit et niht ze lange sprach der chunich do ### wir sin iwer helfe vil pilliche vro ### er sprach ich chuom iv widere in vil kurcen tagen ### daz ir mich habt gesendet daz svlt ir Prvnhilde sagen

<<< Übersicht <<< vorige Seite nächste Seite >>>